@@ -1,3 +1,28 @@
+/************************************************************************
+ FAUST Architecture File
+ Copyright (C) 2003-2019 GRAME, Centre National de Creation Musicale
+ ---------------------------------------------------------------------
+ This Architecture section is free software; you can redistribute it
+ and/or modify it under the terms of the GNU General Public License
+ as published by the Free Software Foundation; either version 3 of
+ the License, or (at your option) any later version.
+ 
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+ 
+ You should have received a copy of the GNU General Public License
+ along with this program; If not, see <http://www.gnu.org/licenses/>.
+ 
+ EXCEPTION : As a special exception, you may create a larger work
+ that contains this FAUST architecture section and distribute
+ that work under terms of your choice, so long as this FAUST
+ architecture section is not modified.
+ 
+ ************************************************************************
+ ************************************************************************/
+ 
 // @notes MODEL, RELEVANTJSONFILE, PLUGNAME and PLUGINNAME are replaced during processing
 using System;
 using System.Text;
@@ -246,15 +271,15 @@ namespace FaustUtilities_MODEL {
 
 		private IntPtr _context;
 
-        #if UNITY_EDITOR_OSX || UNITY_EDITOR_WIN || UNITY_STANDALONE_OSX || UNITY_STANDALONE_WIN || UNITY_WSA || UNITY_WSA_10_0
-        const string _dllName = "PLUGNAME";
-        #elif UNITY_IOS
-        const string _dllName = "__Internal";
-        #elif UNITY_EDITOR || UNITY_ANDROID || UNITY_STANDALONE_LINUX
-        const string _dllName = "PLUGINNAME";
-        #else
-        Debug.LogError("Architecture not supported by the plugin");
-        #endif
+		#if UNITY_EDITOR_OSX || UNITY_EDITOR_WIN || UNITY_STANDALONE_OSX || UNITY_STANDALONE_WIN || UNITY_WSA || UNITY_WSA_10_0
+		const string _dllName = "PLUGNAME";
+		#elif UNITY_IOS
+		const string _dllName = "__Internal";
+		#elif UNITY_EDITOR || UNITY_ANDROID || UNITY_STANDALONE_LINUX
+		const string _dllName = "PLUGINNAME";
+		#else
+		Debug.LogError("Architecture not supported by the plugin");
+		#endif
 
 		// Imports all c++ function to intialize and process the dsp. The methods need to be private
 		[DllImport(_dllName)]
@@ -615,8 +640,6 @@ namespace FaustUtilities_MODEL {
 							}
 						} while (parseChar(ref s , ','));
 						parseChar(ref s, '}');
-					} else {
-						return false;
 					}
 				} while (parseChar(ref s , ','));
 				return parseChar(ref s, ']');
@@ -684,5 +707,4 @@ namespace FaustUtilities_MODEL {
 		public string scale;
 		public string tooltip;
 	}
-
 }
